@@ -4,8 +4,9 @@ OSS SDK: http://help.aliyun.com/view/13438815.html
 """
 
 import os
-from .base import BaseBackend
 from oss.oss_api import OssAPI
+from .base import BaseBackend
+from ..utils import filter_delete_filename_list
 
 
 OSS_HOST = 'oss.aliyuncs.com'
@@ -47,3 +48,9 @@ class OSSBackend(BaseBackend):
 
         if rsp.status != 200:
             raise Exception('put_object_from_file fail: <%s> %s' % (rsp.status, rsp.read()))
+
+    def clean(self, category, keeps):
+        object_list = self.oss.list_objects(self.bucket_name, category+'/')
+
+        delete_filename_list = filter_delete_filename_list(object_list, keeps)
+        self.oss.delete_objects(self.bucket_name, delete_filename_list)
